<?php

namespace Assetdocs\Facility\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Assetdocs\Facility\Http\Requests\FacilityRequest;
use Assetdocs\Facility\Interfaces\FacilityRepositoryInterface;
use Assetdocs\Facility\Models\Facility;

/**
 * Admin API controller class.
 */
class FacilityAdminController extends BaseController
{
    /**
     * Initialize facility controller.
     *
     * @param type FacilityRepositoryInterface $facility
     *
     * @return type
     */
    public function __construct(FacilityRepositoryInterface $facility)
    {
        $this->repository = $facility;
        parent::__construct();
    }

    /**
     * Display a list of facility.
     *
     * @return json
     */
    public function index(FacilityRequest $request)
    {
        $facilities  = $this->repository
            ->setPresenter('\\Assetdocs\\Facility\\Repositories\\Presenter\\FacilityListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $facilities['code'] = 2000;
        return response()->json($facilities) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display facility.
     *
     * @param Request $request
     * @param Model   Facility
     *
     * @return Json
     */
    public function show(FacilityRequest $request, Facility $facility)
    {
        $facility         = $facility->presenter();
        $facility['code'] = 2001;
        return response()->json($facility)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new facility.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(FacilityRequest $request, Facility $facility)
    {
        $facility         = $facility->presenter();
        $facility['code'] = 2002;
        return response()->json($facility)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new facility.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(FacilityRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $facility          = $this->repository->create($attributes);
            $facility          = $facility->presenter();
            $facility['code']  = 2004;

            return response()->json($facility)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show facility for editing.
     *
     * @param Request $request
     * @param Model   $facility
     *
     * @return json
     */
    public function edit(FacilityRequest $request, Facility $facility)
    {
        $facility         = $facility->presenter();
        $facility['code'] = 2003;
        return response()-> json($facility)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the facility.
     *
     * @param Request $request
     * @param Model   $facility
     *
     * @return json
     */
    public function update(FacilityRequest $request, Facility $facility)
    {
        try {

            $attributes = $request->all();

            $facility->update($attributes);
            $facility         = $facility->presenter();
            $facility['code'] = 2005;

            return response()->json($facility)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the facility.
     *
     * @param Request $request
     * @param Model   $facility
     *
     * @return json
     */
    public function destroy(FacilityRequest $request, Facility $facility)
    {
        try {
            $t = $facility->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('facility::facility.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
