<?php

namespace Assetdocs\Facility\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Assetdocs\Facility\Interfaces\FacilityRepositoryInterface;
use Assetdocs\Facility\Repositories\Presenter\FacilityItemTransformer;

/**
 * Pubic API controller class.
 */
class FacilityPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Facility\Interfaces\FacilityRepositoryInterface $facility
     *
     * @return type
     */
    public function __construct(FacilityRepositoryInterface $facility)
    {
        $this->repository = $facility;
        parent::__construct();
    }

    /**
     * Show facility's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $facilities = $this->repository
            ->setPresenter('\\Assetdocs\\Facility\\Repositories\\Presenter\\FacilityListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $facilities['code'] = 2000;
        return response()->json($facilities)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show facility.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $facility = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($facility)) {
            $facility         = $this->itemPresenter($module, new FacilityItemTransformer);
            $facility['code'] = 2001;
            return response()->json($facility)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
