<?php

namespace Assetdocs\Facility\Policies;

use Litepie\User\Contracts\UserPolicy;
use Assetdocs\Facility\Models\Facility;

class FacilityPolicy
{

    /**
     * Determine if the given user can view the facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function view(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facility.facility.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $facility->user_id;
    }

    /**
     * Determine if the given user can create a facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('facility.facility.create');
    }

    /**
     * Determine if the given user can update the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function update(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facility.facility.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $facility->user_id;
    }

    /**
     * Determine if the given user can delete the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facility.facility.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $facility->user_id;
    }

    /**
     * Determine if the given user can verify the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facility.facility.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('facility.facility.verify') 
        && $user->is('manager')
        && $facility->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given facility.
     *
     * @param UserPolicy $user
     * @param Facility $facility
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Facility $facility)
    {
        if ($user->canDo('facility.facility.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
