<?php

namespace Assetdocs\Facility\Providers;

use Illuminate\Support\ServiceProvider;

class FacilityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'facility');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'facility');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('facility', function ($app) {
            return $this->app->make('Assetdocs\Facility\Facility');
        });

                // Bind Facility to repository
        $this->app->bind(
            'Assetdocs\Facility\Interfaces\FacilityRepositoryInterface',
            \Assetdocs\Facility\Repositories\Eloquent\FacilityRepository::class
        );

        $this->app->register(\Assetdocs\Facility\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Assetdocs\Facility\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['facility'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('assetdocs/facility.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/facility')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/facility')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
